@@ -128,7 +128,7 @@ public class MyActivator extends HousekeepingActivator {
                     final int len = string.length();
                     boolean isWhitespace = true;
                     for (int i = 0; isWhitespace && i < len; i++) {
-                        isWhitespace = Character.isWhitespace(string.charAt(i));
+                        isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
                     }
                     return isWhitespace;
                 }
